@@ -33,8 +33,3 @@ GIT_IGNORE_PATH = '.gitignore'
 #-----------------------------------------------------------------------------------------------------------------------
 WEB_SERVERS = []  # required
 REMOTE_ENVIRONMENTS = {}
-
-# Performance
-#-----------------------------------------------------------------------------------------------------------------------
-PROCESSES = 2
-THREADS = 20
